@@ -6,5 +6,5 @@
 ##
 
 class RouteError(Exception):
-  def __init__(self, message):
-    super(RouteError, self).__init__(message)
+  def __init__(self, error):
+    super(RouteError, self).__init__(error)
