@@ -9,8 +9,9 @@ class BucketResource(object):
   def __init__(self, parent):
     self.parent = parent
 
-  def __url_bucket(self, resource):
-    return "/bucket%s" % resource
+  @staticmethod
+  def __url_bucket(resource):
+    return f"/bucket{resource}"
 
   def generate_bucket_url(self, data):
     return self.parent.post(self.__url_bucket("/url/generate"), data)
